@@ -3,16 +3,16 @@
 # Copyright 2004-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -308,11 +308,13 @@ def setupSpeech(prefsDict):
     defaultACSS[acss.ACSS.AVERAGE_PITCH] = 5
     uppercaseACSS = acss.ACSS({acss.ACSS.AVERAGE_PITCH : 6})
     hyperlinkACSS = acss.ACSS({})
+    systemACSS = acss.ACSS({})
 
     voices = {
         settings.DEFAULT_VOICE   : defaultACSS,
         settings.UPPERCASE_VOICE : uppercaseACSS,
-        settings.HYPERLINK_VOICE : hyperlinkACSS
+        settings.HYPERLINK_VOICE : hyperlinkACSS,
+        settings.SYSTEM_VOICE    : systemACSS
     }
 
     prefsDict["enableSpeech"] = True
