@@ -3,16 +3,16 @@
 # Copyright 2007-2009 Sun Microsystems Inc. and Joanmarie Diggs
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -37,6 +37,7 @@ import orca.settings as settings
 import orca.speech as speech
 
 from orca.orca_i18n import _ # for gettext support
+from orca.orca_i18n import ngettext
 
 ########################################################################
 #                                                                      #
@@ -270,16 +271,24 @@ class Script(default.Script):
         # need to detect this and adjust accordingly.]]]
 
         if not oldFocusIsTable and newFocusIsTable:
-            # We've entered a table.  Announce the dimensions.
+            # Translators: this represents the number of rows in a table.
             #
-            line = _("table with %(rows)d rows and %(columns)d columns.") \
-                   % {"rows" : newFocusRows, "columns" : newFocusColumns}
-            speech.speak(line)
+            rowString = ngettext("table with %d row",
+                                 "table with %d rows",
+                                 newFocusRows) % newFocusRows
+            # Translators: this represents the number of columns in a table.
+            #
+            colString = ngettext("%d column",
+                                 "%d columns",
+                                 newFocusColumns) % newFocusColumns
+
+            line = rowString + " " + colString
+            self.presentMessage(line)
 
         elif oldFocusIsTable and not newFocusIsTable:
             # We've left a table.  Announce this fact.
             #
-            speech.speak(_("leaving table."))
+            self.presentMessage(_("leaving table."))
 
         elif oldFocusIsTable and newFocusIsTable:
             # See if we've crossed a cell boundary.  If so, speak
@@ -299,13 +308,13 @@ class Script(default.Script):
                 #
                 line = _("row %(row)d, column %(column)d") \
                        % {"row": newRow, "column": newCol}
-                speech.speak(line)
+                self.presentMessage(line)
             elif newCol != oldCol:
                 # Translators: this represents the column we're
                 # on in a table.
                 #
                 line = _("column %d") % newCol
-                speech.speak(line)
+                self.presentMessage(line)
 
     def isInFindToolbar(self, obj):
         """Examines the current object to identify if it is in the Find
