@@ -3,16 +3,16 @@
 # Copyright 2004-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -29,7 +29,6 @@ import pyatspi
 
 import orca.debug as debug
 import orca.default as default
-import orca.input_event as input_event
 import orca.orca as orca
 import orca.orca_state as orca_state
 import orca.settings as settings
@@ -264,9 +263,9 @@ class Script(default.Script):
             #
             if badWord == _("Completed spell checking"):
                 utterance = _("Spell checking is complete.")
-                speech.speak(utterance)
+                self.presentMessage(utterance)
                 utterance = _("Press Tab and Return to terminate.")
-                speech.speak(utterance)
+                self.presentMessage(utterance)
                 return
 
             # If we have a handle to the gedit text area, then extract out
@@ -489,6 +488,8 @@ class Script(default.Script):
         # apparently get two identical "object:property-change:accessible-name"
         # events.]]]
 
+        lastKey, mods = self.utilities.lastKeyAndModifiers()
+
         # Translators: the "Phrase not found" is the result of a failed
         # find command.  It must be the same as what gedit uses.  We hate
         # keying off stuff like this, but we're forced to do so in this
@@ -496,12 +497,10 @@ class Script(default.Script):
         #
         if event.source.getRole() == pyatspi.ROLE_STATUS_BAR \
            and self.isFocusOnFindDialog() \
-           and orca_state.lastNonModifierKeyEvent \
-           and orca_state.lastNonModifierKeyEvent.event_string == "Return" \
+           and lastKey == "Return" \
            and event.source.name == _("Phrase not found"):
             debug.println(self.debugLevel,
                           "gedit.onNameChanged - phrase not found.")
-
             speech.speak(event.source.name)
 
         # Pass the event onto the parent class to be handled in the default way.
@@ -551,9 +550,8 @@ class Script(default.Script):
         # then speak the current text line, to give an indication of what
         # we've just found.
         #
-        if self.isFocusOnFindDialog() \
-           and orca_state.lastNonModifierKeyEvent \
-           and orca_state.lastNonModifierKeyEvent.event_string == "Return":
+        lastKey, mods = self.utilities.lastKeyAndModifiers()
+        if self.isFocusOnFindDialog() and lastKey == "Return":
             debug.println(self.debugLevel, "gedit.onCaretMoved - find dialog.")
             allComboBoxes = self.utilities.descendantsWithRole(
                 orca_state.locusOfFocus.getApplication(),
@@ -565,7 +563,7 @@ class Script(default.Script):
                 # Translators: this indicates a find command succeeded in
                 # finding something.
                 #
-                speech.speak(_("Phrase found."))
+                self.presentMessage(_("Phrase found."))
                 utterances = self.speechGenerator.generateSpeech(
                     event.source, alreadyFocused=True)
                 speech.speak(utterances)
@@ -573,11 +571,7 @@ class Script(default.Script):
         # If Ctrl+G was used to repeat a find command, speak the line that
         # the caret moved to.
         #
-        if orca_state.lastInputEvent \
-           and isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent)\
-           and orca_state.lastInputEvent.event_string == 'G' \
-           and orca_state.lastInputEvent.modifiers \
-               & (1 << pyatspi.MODIFIER_CONTROL):
+        if lastKey == 'G' and mods & settings.CTRL_MODIFIER_MASK:
             self.sayLine(event.source)
 
         # For everything else, pass the caret moved event onto the parent
